--[[
	This is an extension of the Turbine Window class used to create
	a button composed of 3 images that can be used to a tab panel.
]]--

import "Turbine";
import "Turbine.Utils";
import "Turbine.UI";
import "Turbine.UI.Lotro";

DTabButton = class(Turbine.UI.Control);

function DTabButton:Constructor()
	Turbine.UI.Control.Constructor( self );

	--[[ instance variables ]]--
	self.selected = false;
	self.mouseOver = false;
	self.index = 0;
	self.lastTime = 0;
	
	--[[                    ]]--
		
	-- Set the window to recieve update messages
	self:SetWantsUpdates(true);
	self:SetAllowDrop(true);
	
	-- Create the 3 buttons that will be used to hold
	-- the images
	self.left = Turbine.UI.Button();
	self.left:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.left:SetSize(12,29);
	self.left:SetPosition(0,0);
	self.left:SetZOrder(1);
	self.left:SetParent(self);

	self.center = Turbine.UI.Button();
	self.center:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.center:SetSize(self:GetWidth() - 28,29);
	self.center:SetPosition(12,0);
	self.center:SetZOrder(2);
	self.center:SetParent(self);
	self.center:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);

	self.right = Turbine.UI.Button();
	self.right:SetBlendMode(Turbine.UI.BlendMode.AlphaBlend);
	self.right:SetPosition(self:GetWidth() - 18,0);
	self.right:SetSize(16,29);
	self.right:SetZOrder(3);
	self.right:SetParent(self);
	
	--[[ Mouse Click Event Handlers ]]--
	self.left.MouseClick = function(sender,args)
		myParent = self:GetParent();
		myParent:TabMouseClick(self);	
	end
	self.center.MouseClick = function(sender,args)
		myParent = self:GetParent();
		myParent:TabMouseClick(self);	
	end
	self.right.MouseClick = function(sender,args)
		myParent = self:GetParent();
		myParent:TabMouseClick(self);	
	end
	
	--[[ Mouse Over Event Handlers ]]--
	self.left.MouseEnter = function(sender,args)
		self.mouseOver = true;
	end
	self.center.MouseEnter = function(sender,args)	
		self.mouseOver = true;
	end
	self.right.MouseEnter = function(sender,args)	
		self.mouseOver = true;
	end
	
	self.left.MouseLeave = function(sender,args)	
		self.mouseOver = false;	
	end
	self.center.MouseLeave = function(sender,args)		
		self.mouseOver = false;	
	end
	self.right.MouseLeave = function(sender,args)	
		self.mouseOver = false;	
	end
	
	--[[ Drag Events ]]--
	self.DragEnter = function(sender,args)
		pcall(function ()
			myParent = self:GetParent();
			myParent:DragEnter(self,args);
			end)
	end

	self.DragDrop = function(sender,args)
		pcall(function ()
			myParent = self:GetParent();
			myParent:DragDrop(self,args);
			end)
	end
end

function DTabButton:SetSelected(value)
	self.selected = value;
end

function DTabButton:SetIndex(value)
	self.index = value;
end

function DTabButton:GetIndex()
	return self.index;
end

function DTabButton:SetText(value)
	self.center:SetText(value);
end

function DTabButton:Update(sender,args)

	if(not self:IsVisible()) then
		return;
	elseif(Turbine.Engine.GetGameTime() - self.lastTime > 0.1) then
		self.lastTime = Turbine.Engine.GetGameTime();	

		self.center:SetSize(self:GetWidth() - 28,29);
		self.right:SetPosition(self:GetWidth() - 18,0);
		
		if(self.selected or self.mouseOver) then	
			self.left:SetBackground("DhorPlugins/Extensions/Resources/tab_tier1_middle_front_w.tga");
			self.center:SetBackground("DhorPlugins/Extensions/Resources/tab_tier1_middle_front_n.tga");
			self.right:SetBackground("DhorPlugins/Extensions/Resources/tab_tier1_middle_front_e.tga");		
		else
			self.left:SetBackground("DhorPlugins/Extensions/Resources/tab_tier1_middle_back_w.tga");
			self.center:SetBackground("DhorPlugins/Extensions/Resources/tab_tier1_middle_back_n.tga");
			self.right:SetBackground("DhorPlugins/Extensions/Resources/tab_tier1_middle_back_e.tga");	
		end	
	end
end


