import "Turbine.Utils";

TravelDictionaries = class()

function TravelDictionaries:Constructor()

	-- create the indexed tables that store all the data
	genLocations = IndexedDictionary();	
	hunterLocations = IndexedDictionary();
	wardenLocations = IndexedDictionary();
	racialLocations = IndexedDictionary();
	repLocations = IndexedDictionary();
	
	-- a table to store the number of each type of travel skill
	travelCount = {0,0,0,0,0};
	totalLocations = 0;
	
	self:CreateDictionaries();
   self:GetCounts();	
end

function TravelDictionaries:GetCounts()
	travelCount[1] = hunterLocations:GetCount();	
	travelCount[2] = wardenLocations:GetCount();
	travelCount[3] = genLocations:GetCount();
	travelCount[4] = repLocations:GetCount();
	travelCount[5] = racialLocations:GetCount();
	
	totalLocations = travelCount[1] + travelCount[2] + travelCount[3] + travelCount[4] + travelCount[5];	
end

function TravelDictionaries:GetCount(index)
	return travelCount[index];
end

function TravelDictionaries:GetTotalCount()
   return totalLocations;
end

function TravelDictionaries:GetLocations()
	return genLocations, hunterLocations, wardenLocations, racialLocations, repLocations;
end

function TravelDictionaries:CreateDictionaries()
	-- add the data to custom dictionaries to maintain the order

	hunterLocations:AddData("Return to Camp","0x7000A2C1");
	hunterLocations:AddData("Guide to Bree","0x70003F42");
	hunterLocations:AddData("Guide to Thorin's Hall","0x70003F41");
	hunterLocations:AddData("Guide to Michel Delving","0x7000A2C3");
	hunterLocations:AddData("Guide to Esteldn","0x70003F43");
	hunterLocations:AddData("Guide to Evendim","0x7000A2C4");
	hunterLocations:AddData("Guide to Ost Guruth","0x7000A2C2");
	hunterLocations:AddData("Guide to Rivendell","0x70003F44");
	hunterLocations:AddData("Guide to Sri-Kyl","0x70017C82");
	hunterLocations:AddData("Guide to West Angmar","0x7000A2C5");
	hunterLocations:AddData("Guide to East Angmar","0x7000A2C6");
	hunterLocations:AddData("Guide to Echad Dnann","0x70017C81");
	hunterLocations:AddData("Guide to Twenty-First Hall","0x70017C7A");
	hunterLocations:AddData("Guide to Mirk-Eaves","0x7001F459");
	hunterLocations:AddData("Guide to Harndirion","0x700235EF");

	wardenLocations:AddData("Muster in Ost Guruth","0x70014786");
	wardenLocations:AddData("Muster in Esteldn","0x70014798");
	wardenLocations:AddData("Muster in Evendim","0x7001478E");
	wardenLocations:AddData("Muster in Rivendell","0x70014791");	
	wardenLocations:AddData("Muster in Sri-Kyl","0x700237D4");
	wardenLocations:AddData("Muster in Twenty-First Hall","0x7001819E");
	wardenLocations:AddData("Muster in Mirk-Eaves","0x7001F45C");
	wardenLocations:AddData("Muster in Harndirion","0x700235EB");					

	racialLocations:AddData("Return to Bree","0x700062F6");
	racialLocations:AddData("Return to Shire","0x700062C8");
	racialLocations:AddData("Return to Thorin's","0x70006346");
	racialLocations:AddData("Return to Rivendell","0x7000631F");	

	genLocations:AddData("Personal House","0x7000D046");
	genLocations:AddData("Kinship House","0x7000D047");

	repLocations:AddData("Return to Thorin's","0x7001BF91");
	repLocations:AddData("Return to Bree","0x7001BF90");
	repLocations:AddData("Return to Shire","0x70023262");
	repLocations:AddData("Return to Rivendell","0x70023263");
	repLocations:AddData("Return to Mirkwood","0x7001F374");
	repLocations:AddData("Return to Ost Guruth","0x70020441");
	repLocations:AddData("Return to Enedwaith","0x70021FA2");
end





IndexedDictionary = class() 

function IndexedDictionary:Constructor()

	self.listOfKeys = { };
	self.dataPairs = { };
	self.numberOfPairs = 0;
end

function IndexedDictionary:GetCount()
	return self.numberOfPairs;
end

function IndexedDictionary:AddData(key, data)
	self.numberOfPairs = self.numberOfPairs + 1;

	table.insert(self.listOfKeys,key);
	self.dataPairs[key] = data;

end

function IndexedDictionary:InsertData(index, key, data)
	self.numberOfPairs = self.numberOfPairs + 1;

	table.insert(self.listOfKeys, index, key);
	self.dataPairs[key] = data;
end

function IndexedDictionary:RemoveAtIndex(index)
	
	self.location = 0;
	self.counter = 0;
	
	for k,v in pairs(self.dataPairs) do
		self.counter = self.counter + 1;
		if(k == self.listOfKeys[index]) then
			self.location = self.counter;
		end
	end

	table.remove(self.dataPairs,self.location);
	table.remove(self.listOfKeys,index);

	self.numberOfPairs = self.numberOfPairs - 1;
end

function IndexedDictionary:KeyAtIndex(index)
	local string = self.listOfKeys[index];
	return string;
end

function IndexedDictionary:DataAtIndex(index)
	local string = self.listOfKeys[index];
	local data = self.dataPairs[string];

	return data;
end

function IndexedDictionary:PairAtIndex(index)
	local string = self.listOfKeys[index];
	local data = self.dataPairs[string];

	return string,data;
end

function IndexedDictionary:DataByKey(key)
	return self.dataPairs[key];
end

function IndexedDictionary:IndexByKey(key)
	if(self.listOfKeys == { }) then
		return -1;
	end

	for i = 1,table.getn(self.listOfKeys),1 do
		if(self.listOfKeys[i] == key) then
			return i;
		end
	end
	
	return -1;
end


