import "Turbine.Utils";
import "DhorPlugins.Utils.BitOps";
import "DhorPlugins.Extensions";

SettingsMenu = class(Turbine.UI.ContextMenu)

function SettingsMenu:Constructor(parentWindow)
	Turbine.UI.ContextMenu.Constructor( self );

	self.race = 1;
	self.class = 1;
	self.mode = 1;
	self.filters = 0x0F;

	self.parent = parentWindow;

	-- create the filter sub menu
	Filters = DhorPlugins.Extensions.DMenuList("Filters");
	self.Filters1 = Turbine.UI.MenuItem("Show Generic Travels");
	self.Filters2 = Turbine.UI.MenuItem("Show Racial Travels");
	self.Filters3 = Turbine.UI.MenuItem("Show Reputation Travels");
	self.Filters4 = Turbine.UI.MenuItem("Show Hunter Travels");
	self.Filters5 = Turbine.UI.MenuItem("Show Warden Travels");
	FilterItems = Filters:GetItems();
	FilterItems:Add(self.Filters1);
	FilterItems:Add(self.Filters2);
	FilterItems:Add(self.Filters3);
	FilterItems:Add(self.Filters4);
   FilterItems:Add(self.Filters5);
   
	-- create the mode sub menu
	Mode = DhorPlugins.Extensions.DMenuList("Mode");
	self.Mode1 = Turbine.UI.MenuItem("Text List");
	self.Mode2 = Turbine.UI.MenuItem("Icon Grid");
	self.Mode3 = Turbine.UI.MenuItem("Carousel");
	self.Mode4 = Turbine.UI.MenuItem("Pulldown List");
	ModeItems = Mode:GetItems();
	ModeItems:Add(self.Mode1);
	ModeItems:Add(self.Mode2);
	ModeItems:Add(self.Mode3);
	ModeItems:Add(self.Mode4);

	-- create the class sub menu
	--ClassMenu = DhorPlugins.Extensions.DMenuList("Class");
	--self.Class1 = Turbine.UI.MenuItem("Hunter");
	--self.Class2 = Turbine.UI.MenuItem("Warden");
	--ClassItems = ClassMenu:GetItems();
	--ClassItems:Add(self.Class1);
	--ClassItems:Add(self.Class2);

	-- create the racial sub class
	--RaceMenu = DhorPlugins.Extensions.DMenuList("Race");
	--self.RaceMenu1 = Turbine.UI.MenuItem("Man");
	--self.RaceMenu2 = Turbine.UI.MenuItem("Hobbit");
	--self.RaceMenu3 = Turbine.UI.MenuItem("Dwarf");
	--self.RaceMenu4 = Turbine.UI.MenuItem("Elf");
	--RaceItems = RaceMenu:GetItems();
	--RaceItems:Add(self.RaceMenu1);
	--RaceItems:Add(self.RaceMenu2);
	--RaceItems:Add(self.RaceMenu3);
	--RaceItems:Add(self.RaceMenu4);
	
	-- create the menu item to add map home
	MapMenu = DhorPlugins.Extensions.DMenuList("Add Map");	

	-- add everything to the main menu
	menuItems = self:GetItems();
	menuItems:Add(Filters);
	menuItems:Add(Mode);
	--menuItems:Add(ClassMenu);
	--menuItems:Add(RaceMenu);
	menuItems:Add(MapMenu);

	-- set up the event handler
	-- loop through top level of menu
	for i = 1, menuItems:GetCount(),1 do
		local menuList = menuItems:Get(i);

		-- loop through the sub menu
		for j = 1, menuList:GetCount(),1 do
			local menuItem = menuList:Get(j);	

			-- set the function to handle the event	
			menuItem.Click = function(sender,args)
				self:Update(sender:GetText());
			end
		end
	end
	
	-- handle the last item's event
	menuItems:Get(3).Click = function(sender,args)
		self:Update(sender:GetText());
	end

	self:SetSelections();

end

function SettingsMenu:SetSelections()
	
	-- set the filters using the BitOps functions
	self.Filters1:SetChecked(hasbit(self.filters,bit(1)));
	self.Filters2:SetChecked(hasbit(self.filters,bit(2)));
	self.Filters3:SetChecked(hasbit(self.filters,bit(3)));
	self.Filters4:SetChecked(hasbit(self.filters,bit(4)));
	self.Filters5:SetChecked(hasbit(self.filters,bit(5)));

	-- set the mode
	self.Mode1:SetChecked(self.mode == 1);
	self.Mode2:SetChecked(self.mode == 2);
	self.Mode3:SetChecked(self.mode == 3);
	self.Mode4:SetChecked(self.mode == 4);

	-- set the class
	--self.Class1:SetChecked(self.class == 1);
	--self.Class2:SetChecked(self.class == 2);

	-- set the race
	--self.RaceMenu1:SetChecked(self.race == 1);
	--self.RaceMenu2:SetChecked(self.race == 2);
	--self.RaceMenu3:SetChecked(self.race == 3);
	--self.RaceMenu4:SetChecked(self.race == 4);
end

function SettingsMenu:GetSettings()

	return self.race,self.class,self.mode,self.filters;
end

function SettingsMenu:SetSettings(s1,s2,s3,s4)
	self.race = s1;
	self.class = s2;
	self.mode = s3;
	self.filters = s4;

	self:SetSelections();
end

function SettingsMenu:Update(string)


	if(string == "Show Generic Travels") then
		self.filters = togglebit(self.filters,bit(1));
	elseif(string == "Show Racial Travels") then
		self.filters = togglebit(self.filters,bit(2));
	elseif(string == "Show Reputation Travels") then
		self.filters = togglebit(self.filters,bit(3));
	elseif(string == "Show Hunter Travels") then
		self.filters = togglebit(self.filters,bit(4));
	elseif(string == "Show Warden Travels") then
		self.filters = togglebit(self.filters,bit(5));
	elseif(string == "Text List") then
		self.mode = 1;
	elseif(string == "Icon Grid") then
		self.mode = 2;
	elseif(string == "Carousel") then
		self.mode = 3;
	elseif(string == "Pulldown List") then
      self.mode = 4;
	--elseif(string == "Hunter") then
		--self.class = 1;
	--elseif(string == "Warden") then
		--self.class = 2;
	--elseif(string == "Man") then
		--self.race = 1;
	--elseif(string == "Hobbit") then
		--self.race = 2;
	--elseif(string == "Dwarf") then
		--self.race = 3;
	--elseif(string == "Elf") then
		--self.race = 4;
	elseif(string == "Add Map") then
		self.parent:SetMapHome();
	end

	self:SetSelections();

	self.parent:UpdateSettings();
end




