import "Turbine";
import "Turbine.Gameplay";
import "Turbine.UI";
import "Turbine.UI.Lotro";
import "DhorPlugins.Extensions";
import "DhorPlugins.Travel.IndexedDictionary";
import "DhorPlugins.Travel.SettingsMenu";
import "DhorPlugins.Utils.BitOps";
import "DhorPlugins.Travel.OrendarUIMods.ComboBox"

--[[ This is the window for the text list tab of the 	]]--
--[[ Travel UI.  It handles creating all UI controls on ]]--
--[[ the tab, and updating the UI when the settings are	]]--
--[[ changed.											]]--
--[[ Functions:											]]--
--[[		Constructor() - initializes the window and	]]--
--[[			creates all the sub controls			]]--
--[[		SetItems() - creates the listbox and adds	]]--
--[[			all the labels with the proper shortcut ]]--
--[[			data									]]--
--[[		AddItem() - subroutine of SetItems			]]--
--[[		ChangeItem() - updates the listbox and the	]]--
--[[			quickslot when the player selects a new	]]--
--[[			item on the list						]]--
--[[		SetScrollBar() - set up the scrollbar based	]]--
--[[			on the size of the grid					]]--
--[[		SetRationCount() - updates the label that	]]--
--[[			shows the number of travel rations		]]--

TravelPulldownTab = class( Turbine.UI.Control );

function TravelPulldownTab:Constructor()
	Turbine.UI.Control.Constructor( self );
	
		-- for displaying the number of travel rations
	self.rationCount = 0;
	self.rationLabel = Turbine.UI.Label();
	self.rationLabel:SetPosition(0,0);
	self.rationLabel:SetSize(180,20);
	self.rationLabel:SetForeColor(Turbine.UI.Color(1,0,0.5,0));
	self.rationLabel:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleCenter);
	self.rationLabel:SetText("Travel Rations:");
	self.rationLabel:SetVisible(true);
	self.rationLabel:SetParent(self);
	self.rationLabel:SetZOrder(100);
	
	-- this label is used to catch wheel moves
	self.scrollLabel = Turbine.UI.Label();
	self.scrollLabel:SetSize(180,155);
	self.scrollLabel:SetPosition(0,20);
	self.scrollLabel:SetParent(self);
	
	-- the pulldown box
	self.pulldown = DhorPlugins.Travel.OrendarUIMods.ComboBox();
	self.pulldown:SetPosition(0,20);
	self.pulldown:SetSize(200,30);
	self.pulldown:SetParent(self);
	self.pulldown:SetVisible(true);
   
   -- the quickslot for the shortcut
   self.quickslot = Turbine.UI.Lotro.Quickslot();
   self.quickslot:SetSize(36,36);
   self.quickslot:SetPosition(82,55);
   self.quickslot:SetZOrder(19);
   self.quickslot:SetParent(self);
   self.quickslot:SetVisible(true);   
   
	self:SetItems();
   
	--[[  EVENT HANDLERS  ]]--
	
	-- make sure we listen for key presses
	self:SetWantsUpdates(true);
	
	-- check for a right mouse button event to open menu
	self.MouseClick = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Right) then
			menu:ShowMenu();
		end
	end
   
   self.MouseDown = function( sender, args )
      self.pulldown:CloseDropDown();
   end		
	
	-- check for a right mouse button event to open menu
	self.rationLabel.MouseClick = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Right) then
			menu:ShowMenu();
		end
	end
   
   self.rationLabel.MouseDown = function( sender, args )
      self.pulldown:CloseDropDown();
   end	
	
	self.rationLabel.MouseWheel = function( sender, args )		
			self:DoScroll(sender,args);		
	end
	
	-- check for a right mouse button event to open menu
	self.scrollLabel.MouseClick = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Right) then
			menu:ShowMenu();
		end
	end
   
   self.scrollLabel.MouseDown	= function (sender,args)
      self.pulldown:CloseDropDown();
   end      	
	
	-- check for mouse wheel movements
	self.scrollLabel.MouseWheel = function( sender, args )		
			self:DoScroll(sender,args);		
	end
   
   self.pulldown.MouseWheel = function( sender, args )
         self:DoScroll(sender,args);
   end
   
   self.quickslot.MouseClick = function( sender, args )
		if(args.Button == Turbine.UI.MouseButton.Right) then
			menu:ShowMenu();
		end
	end	
end

function TravelPulldownTab:DoScroll(sender,args)

end

function TravelPulldownTab:SetItems()
   self.pulldown = DhorPlugins.Travel.OrendarUIMods.ComboBox();
	self.pulldown:SetPosition(0,20);
	self.pulldown:SetSize(200,30);
	self.pulldown:SetParent(self);
	self.pulldown:SetVisible(true);
	
	counter = 1;
	for i = 1,table.getn(travelShortcuts),1 do
	    if(travelShortcuts[i]:IsEnabled()) then
	       if(hasbit(settings.filters,bit(travelShortcuts[i]:GetTravelType()))) then
	          self.pulldown:AddItem(travelShortcuts[i]:GetName(),i);
	          counter = counter + 1;
	       end
	    end 
	end
	
   self.pulldown.SelectedIndexChanged = function( sender, args )
      self.quickslot:SetShortcut(travelShortcuts[sender:GetSelection()]);
   end	
end

function TravelPulldownTab:SetRationCount(value)
	self.rationCount = value;
	self.rationLabel:SetText("Travel Rations: " .. self.rationCount)
end

function TravelPulldownTab:SetSize(width, height)
    
   Turbine.UI.Control.SetSize(self,width,height);

   self.rationLabel:SetSize(self:GetWidth(),20);
   self.scrollLabel:SetSize(self:GetWidth(),self:GetHeight());
   
   Turbine.UI.Control.SetOpacity(self,1);
end

function TravelPulldownTab:ClosePulldown()
   self.pulldown:CloseDropDown()
end
